"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoBillingPeriodInfoTypedDict(TypedDict):
    end_time: NotRequired[str]
    period: NotRequired[str]
    r"""e.g., \"monthly\", \"yearly\" """
    start_time: NotRequired[str]


class DtoBillingPeriodInfo(BaseModel):
    end_time: Optional[str] = None

    period: Optional[str] = None
    r"""e.g., \"monthly\", \"yearly\" """

    start_time: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["end_time", "period", "start_time"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
