"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetInvoiceRequestTypedDict(TypedDict):
    id: str
    r"""Invoice ID"""
    expand_by_source: NotRequired[bool]
    r"""Include source-level price breakdown for usage line items (legacy)"""
    group_by: NotRequired[List[str]]
    r"""Group usage breakdown by specified fields (e.g., source, feature_id, properties.org_id)"""


class GetInvoiceRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Invoice ID"""

    expand_by_source: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Include source-level price breakdown for usage line items (legacy)"""

    group_by: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Group usage breakdown by specified fields (e.g., source, feature_id, properties.org_id)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["expand_by_source", "group_by"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
