"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoCustomAnalyticItemTypedDict(TypedDict):
    feature_name: NotRequired[str]
    r"""Name of the feature this applies to"""
    id: NotRequired[str]
    name: NotRequired[str]
    r"""Calculation name (e.g., \"Revenue per Minute\")"""
    type: NotRequired[str]
    r"""\"feature\", \"meter\", \"event_name\" """
    value: NotRequired[str]


class DtoCustomAnalyticItem(BaseModel):
    feature_name: Optional[str] = None
    r"""Name of the feature this applies to"""

    id: Optional[str] = None

    name: Optional[str] = None
    r"""Calculation name (e.g., \"Revenue per Minute\")"""

    type: Optional[str] = None
    r"""\"feature\", \"meter\", \"event_name\" """

    value: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["feature_name", "id", "name", "type", "value"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
