"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_tenantbillingdetails import (
    DtoTenantBillingDetails,
    DtoTenantBillingDetailsTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoTenantResponseTypedDict(TypedDict):
    billing_details: NotRequired[DtoTenantBillingDetailsTypedDict]
    created_at: NotRequired[str]
    id: NotRequired[str]
    metadata: NotRequired[Dict[str, str]]
    name: NotRequired[str]
    status: NotRequired[str]
    updated_at: NotRequired[str]


class DtoTenantResponse(BaseModel):
    billing_details: Optional[DtoTenantBillingDetails] = None

    created_at: Optional[str] = None

    id: Optional[str] = None

    metadata: Optional[Dict[str, str]] = None

    name: Optional[str] = None

    status: Optional[str] = None

    updated_at: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "billing_details",
                "created_at",
                "id",
                "metadata",
                "name",
                "status",
                "updated_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
