"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel
from flexprice_py.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ListSubscriptionSchedulesRequestTypedDict(TypedDict):
    subscription_id: str
    r"""Subscription ID"""


class ListSubscriptionSchedulesRequest(BaseModel):
    subscription_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Subscription ID"""
