"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.models.components import (
    dto_updatetaxraterequest as components_dto_updatetaxraterequest,
)
from flexprice_py.types import BaseModel
from flexprice_py.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateTaxRateRequestTypedDict(TypedDict):
    id: str
    r"""Tax rate ID"""
    body: components_dto_updatetaxraterequest.DtoUpdateTaxRateRequestTypedDict
    r"""Tax rate to update"""


class UpdateTaxRateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Tax rate ID"""

    body: Annotated[
        components_dto_updatetaxraterequest.DtoUpdateTaxRateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Tax rate to update"""
