"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_customerusagesummaryresponse import (
    DtoCustomerUsageSummaryResponse,
    DtoCustomerUsageSummaryResponseTypedDict,
)
from .dto_subscriptionresponse import (
    DtoSubscriptionResponse,
    DtoSubscriptionResponseTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoTenantBillingUsageTypedDict(TypedDict):
    subscriptions: NotRequired[List[DtoSubscriptionResponseTypedDict]]
    usage: NotRequired[DtoCustomerUsageSummaryResponseTypedDict]


class DtoTenantBillingUsage(BaseModel):
    subscriptions: Optional[List[DtoSubscriptionResponse]] = None

    usage: Optional[DtoCustomerUsageSummaryResponse] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["subscriptions", "usage"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
