"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoEnvironmentResponseTypedDict(TypedDict):
    created_at: NotRequired[str]
    id: NotRequired[str]
    name: NotRequired[str]
    type: NotRequired[str]
    updated_at: NotRequired[str]


class DtoEnvironmentResponse(BaseModel):
    created_at: Optional[str] = None

    id: Optional[str] = None

    name: Optional[str] = None

    type: Optional[str] = None

    updated_at: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["created_at", "id", "name", "type", "updated_at"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
